@@ -1,7 +1,7 @@
 package WWW::PAUSE::Simple;
 
-our $DATE = '2016-01-17'; # DATE
-our $VERSION = '0.29'; # VERSION
+our $DATE = '2016-06-02'; # DATE
+our $VERSION = '0.30'; # VERSION
 
 use 5.010001;
 use strict;
@@ -162,7 +162,6 @@ $SPEC{upload_files} = {
         delay => {
             summary => 'Pause a number of seconds between files',
             schema => ['duration*'],
-            'x.perl.coerce_to' => 'int(secs)',
             description => <<'_',
 
 If you upload a lot of files (e.g. 7-10 or more) at a time, the PAUSE indexer
@@ -175,7 +174,6 @@ _
         group_delay => {
             summary => 'Pause a number of seconds between groups of files',
             schema => 'duration*',
-            'x.perl.coerce_to' => 'int(secs)',
             description => <<'_',
 
 As an alternative to the `delay` option, you can also use this option. This will
@@ -287,6 +285,8 @@ sub upload_files {
         $res->[3] //= {};
         $res->[3]{item_id} = $file;
         $log->tracef("Result of upload: %s", $res);
+        $log->warnf("Upload of %s failed: %s - %s", $file, $res->[0], $res->[1])
+            if $res->[0] !~ /^2/;
         $envres->add_result($res->[0], $res->[1], $res->[3]);
 
       DELAY:
@@ -400,11 +400,8 @@ sub list_files {
     }
     my %resmeta;
     if ($args{detail}) {
-        $resmeta{format_options} = {
-            any => {
-                table_column_orders => [[qw/name size mtime is_scheduled_for_deletion deletion_time/]],
-            },
-        };
+        $resmeta{'table.fields'} =
+            [qw/name size mtime is_scheduled_for_deletion deletion_time/];
     }
     [200, "OK", \@files, \%resmeta];
 }
@@ -514,11 +511,7 @@ sub list_dists {
         $resmeta{"func.old_files"} = \@old_files;
     }
     if ($args{detail}) {
-        $resmeta{format_options} = {
-            any => {
-                table_column_orders => [[qw/name version is_dev_version file/]],
-            },
-        };
+        $resmeta{'table.fields'} = [qw/name version is_dev_version file/];
     }
     [200, "OK", \@dists, \%resmeta];
 }
@@ -850,11 +843,7 @@ sub list_modules {
 
     my %resmeta;
     if ($args{detail}) {
-        $resmeta{format_options} = {
-            any => {
-                table_column_orders => [[qw/module userid type owner/]],
-            },
-        };
+        $resmeta{'table.fields'} =[qw/module userid type owner/];
     }
     [200, "OK", \@mods, \%resmeta];
 }
@@ -874,7 +863,7 @@ WWW::PAUSE::Simple - An API for PAUSE
 
 =head1 VERSION
 
-This document describes version 0.29 of WWW::PAUSE::Simple (from Perl distribution WWW-PAUSE-Simple), released on 2016-01-17.
+This document describes version 0.30 of WWW::PAUSE::Simple (from Perl distribution WWW-PAUSE-Simple), released on 2016-06-02.
 
 =head1 SYNOPSIS
 
@@ -1111,7 +1100,7 @@ Return value:  (any)
 
 List modules (permissions).
 
-This function is not exportable.
+This function is not exported.
 
 Arguments ('*' denotes required arguments):
 
@@ -1257,7 +1246,7 @@ Return value:  (any)
 
 Upload file(s).
 
-This function is not exportable.
+This function is not exported.
 
 This function supports dry-run operation.
 
@@ -1336,15 +1325,6 @@ Return value:  (any)
 
 =for Pod::Coverage ^(upload_file|set_account_info|set_password)$
 
-=head1 SEE ALSO
-
-L<CPAN::Uploader> which also does uploading from CLI.
-
-L<WWW::PAUSE::CleanUpHomeDir> which can clean old releases from your PAUSE
-account (CLI example is provided script).
-
-L<https://perlancar.wordpress.com/2015/03/25/interacting-with-pause-using-cli/>
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/WWW-PAUSE-Simple>.
@@ -1361,6 +1341,15 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<CPAN::Uploader> which also does uploading from CLI.
+
+L<WWW::PAUSE::CleanUpHomeDir> which can clean old releases from your PAUSE
+account (CLI example is provided script).
+
+L<https://perlancar.wordpress.com/2015/03/25/interacting-with-pause-using-cli/>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
